Generate dosing decisions (E, S, D or DU) of the BOIN design for user-specified number of participants.
get_decision_boin(pT,
EI,
npts)get_decision_boin() returns:
(1) a dataframe containing the decisions (E, S, D or DU) for each combination of y and n ($tab),
(2) a list ($setup) containing user input parameters, such as target, EI, npts, etc.
a numeric value that specifies the target DLT rate (\(p_T\)).
a vector that specifies the equivalence interval (EI).
the number of participants within which dosing decisions are generated.
Denote the current dose \(d\). Let \(n_d\) and \(y_d\) represent the number of participants treated at dose \(d\) and the number of participants experienced DLT, respectively. Let \(p_d\) be the toxicity probability at dose \(d\). Also, denote \(\frac{y_d}{n_d}\) the observed toxicity rate at the current dose.
The BOIN design uses the following decision rules: if \(\frac{y_d}{n_d}\) is lower than or equal to the escalation boundary, the decision is to escalate to the next higher dose; if \(\frac{y_d}{n_d}\) is higher than the de-escalation boundary, the decision is to the next lower dose; otherwise, the decision is to stay at the current dose.
Also, the BOIN design includes a dose exclusion rule. Let \(p_T\) represents the target DLT rate. If \(Pr(p_d > p_T | y_d , n_d ) > 0.95\), dose \(d\) and those higher than \(d\) are removed from the trial since they are deemed excessively toxic.
Liu S. and Yuan, Y. (2015). Bayesian Optimal Interval Designs for Phase I Clinical Trials, Journal of the Royal Statistical Society: Series C, 64, 507-523.
get_decision_boin(pT = 0.25,
EI = c(0.15,0.35),
npts = 12)
Run the code above in your browser using DataLab